@@ -20,6 +20,8 @@
 #include "qalculateunitsdialog.h"
 #include "qalculate_tde_utils.h"
 #include "qalculateeditunitdialog.h"
+#include <vector>
+#include <string>
 #include <kpushbutton.h>
 #include <tqsplitter.h>
 #include <tqvbox.h>
@@ -37,7 +39,7 @@
 #include <kstdguiitem.h>
 
 extern tree_struct unit_cats;
-extern vector<void*> ia_units;
+extern std::vector<void*> ia_units;
 extern PrintOptions printops;
 extern EvaluationOptions evalops;
 
@@ -115,23 +117,23 @@ QalculateUnitsDialog::QalculateUnitsDialog(TQWidget *parent, const char *name) :
 
 	resize(TQSize(675, 425).expandedTo(size()));
 
-	connect(buttonClose, SIGNAL(clicked()), this, SLOT(close()));
-	connect(newButton, SIGNAL(clicked()), this, SLOT(newUnit()));
-	connect(editButton, SIGNAL(clicked()), this, SLOT(editUnit()));
-	connect(deleteButton, SIGNAL(clicked()), this, SLOT(deleteUnit()));
-	connect(deactivateButton, SIGNAL(clicked()), this, SLOT(deactivateUnit()));
-	connect(insertButton, SIGNAL(clicked()), this, SLOT(insertUnit()));
-	connect(convertResultButton, SIGNAL(clicked()), this, SLOT(convertResult()));
-	connect(unitView, SIGNAL(selectionChanged()), this, SLOT(unitSelected()));
-	connect(unitView, SIGNAL(doubleClicked(TQListViewItem*)), this, SLOT(unitDoubleClicked(TQListViewItem*)));
-	connect(categoryView, SIGNAL(selectionChanged()), this, SLOT(categorySelected()));
-	connect(toCombo, SIGNAL(activated(int)), this, SLOT(toUnitSelected(int)));
-	connect(convertButton, SIGNAL(clicked()), this, SLOT(convertClicked()));
-	connect(fromEdit, SIGNAL(returnPressed()), this, SLOT(convert()));
-	connect(toEdit, SIGNAL(returnPressed()), this, SLOT(convertReversed()));
-	connect(fromEdit, SIGNAL(lostFocus()), this, SLOT(convert()));
-	connect(toEdit, SIGNAL(lostFocus()), this, SLOT(convertReversed()));
-	connect(helpButton, SIGNAL(clicked()), this, SLOT(slotHelp()));
+	connect(buttonClose, TQ_SIGNAL(clicked()), this, TQ_SLOT(close()));
+	connect(newButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(newUnit()));
+	connect(editButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(editUnit()));
+	connect(deleteButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(deleteUnit()));
+	connect(deactivateButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(deactivateUnit()));
+	connect(insertButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(insertUnit()));
+	connect(convertResultButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(convertResult()));
+	connect(unitView, TQ_SIGNAL(selectionChanged()), this, TQ_SLOT(unitSelected()));
+	connect(unitView, TQ_SIGNAL(doubleClicked(TQListViewItem*)), this, TQ_SLOT(unitDoubleClicked(TQListViewItem*)));
+	connect(categoryView, TQ_SIGNAL(selectionChanged()), this, TQ_SLOT(categorySelected()));
+	connect(toCombo, TQ_SIGNAL(activated(int)), this, TQ_SLOT(toUnitSelected(int)));
+	connect(convertButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(convertClicked()));
+	connect(fromEdit, TQ_SIGNAL(returnPressed()), this, TQ_SLOT(convert()));
+	connect(toEdit, TQ_SIGNAL(returnPressed()), this, TQ_SLOT(convertReversed()));
+	connect(fromEdit, TQ_SIGNAL(lostFocus()), this, TQ_SLOT(convert()));
+	connect(toEdit, TQ_SIGNAL(lostFocus()), this, TQ_SLOT(convertReversed()));
+	connect(helpButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotHelp()));
 
 }
 
@@ -421,7 +423,7 @@ void QalculateUnitsDialog::categorySelected() {
 		b_inactive = true;
 	}
 	if(!b_all && !no_cat && !b_inactive && selected_category[0] == '/') {
-		string str = selected_category.ascii();
+		std::string str = selected_category.ascii();
 		str.erase(str.begin());
 		for(size_t i = 0; i < CALCULATOR->units.size(); i++) {
 			if(CALCULATOR->units[i]->isActive() && CALCULATOR->units[i]->category().substr(0, selected_category.length() - 1) == str) {
@@ -429,7 +431,7 @@ void QalculateUnitsDialog::categorySelected() {
 			}
 		}
 	} else {
-		string str = selected_category.ascii();
+		std::string str = selected_category.ascii();
 		for(size_t i = 0; i < CALCULATOR->units.size(); i++) {
 			if((b_inactive && !CALCULATOR->units[i]->isActive()) || (CALCULATOR->units[i]->isActive() && (b_all || (no_cat && CALCULATOR->units[i]->category().empty()) || (!b_inactive && CALCULATOR->units[i]->category() == str)))) {
 				addUnitTreeItem(CALCULATOR->units[i]);
